# Bitsight API v1

## API information

- 1.0.0
- Servers
  - <https://api.bitsighttech.com/v1> - production server
  - <https://service.bitsighttech.com/customer-api/v1> - testing server

## Other files

- `bitsight.v1.endpoints.md` list of endpoints
- `../../src/birre/resources/apis/bitsight.v1.schema.json` full API definition. DO NOT READ! For details look up API excerpt files in sub folders (see next chapter)

## Folder Structure for API excerpt files

### Core Files (v1/)

- `openapi.json` - OpenAPI specification
- `info.json` - API information
- `servers.json` - Server definitions
- `tags.json` - Endpoint tags
- `security.json` - Security definitions
- `x-common-definitions.json` - Common definitions

### Components (v1/components/)

- `schemas.json` - Data schemas
- `parameters.json` - Reusable parameters
- `responses.json` - Response definitions
- `securitySchemes.json` - Security schemes

### Endpoints by Starting Letter (v1/paths/)

- `a.json` - Endpoints starting with 'a'
- `b.json` - Endpoints starting with 'b'
- `c.json` - Endpoints starting with 'c'
- `d.json` - Endpoints starting with 'd'
- `e.json` - Endpoints starting with 'e'
- `f.json` - Endpoints starting with 'f'
- `g.json` - Endpoints starting with 'g'
- `i.json` - Endpoints starting with 'i'
- `j.json` - Endpoints starting with 'j'
- `k.json` - Endpoints starting with 'k'
- `l.json` - Endpoints starting with 'l'
- `m.json` - Endpoints starting with 'm'
- `n.json` - Endpoints starting with 'n'
- `o.json` - Endpoints starting with 'o'
- `p.json` - Endpoints starting with 'p'
- `r.json` - Endpoints starting with 'r'
- `s.json` - Endpoints starting with 's'
- `t.json` - Endpoints starting with 't'
- `u.json` - Endpoints starting with 'u'
- `v.json` - Endpoints starting with 'v'
